package org.honours.gui;

import java.util.List;

import org.expeditee.gui.*;
import org.expeditee.items.Text;

import org.honours.Main;
import org.honours.collection.*;

/**
 * This class is used for displaying the
 * various different overlays/interfaces available.
 * @author Korii
 */
public class Interfaces {
	
	//various frame names for the different interface overlays.
	public static final String MAIN_INTERFACE_OVERLAY = "interface-overlays1";
	public static final String NAVIGATION_OVERLAY = "interface-overlays2";
	public static final String LAYERS_BACK_BTN_OVERLAY = "interface-overlays3";
	public static final String TOGGLE_TOOLS_OVERLAY = "interface-overlays4";
	//public static final String DISPLAY_LAYERS_OVERLAY = "interface-overlays5";
	public static final String BLANK_TOOLBAR_OVERLAY = "interface-overlays6";
	//public static final String BLANK_DISPLAY_LAYERS_OVERLAY = "interface-overlays7";
	
	//TODO: Overlay for hiding notes.
	public static final String BLANK_HIDE_NOTES_OVERLAY = "interface-overlays9";
	
	public static final String BLANK_TOGGLER_OVERLAY = "interface-overlays10";
	
	private static final String AO_TEXT3 = "@ao:3";
	private static final String AO_TEXT4 = "@ao:4";

	//used to determine positioning of the various @ao:3/4 text items.
	private static int _mainOverAoX = 1272;
	private static int _mainOverAoY = 130;
	
	private static int _toolbarAoX = 1272;
	private static int _toolbarAoY = 130;
	
	private static int _toggleAoX = 1272;
	private static int _toggleAoY = 94;
	
	private static int _notesAoX = 1272;
	private static int _notesAoY = 58;
	
	private static String _overlayAnnotationData = "overlay-annotation";
	
	
	/** Method to set up overlay locations relative to the screen size. **/
	public static void setUpOverlayLocations(){
		
	}
	
	/**
	 * This method sets up the main overlay on the profile
	 * frame.
	 * @param frame - frame to add the main overlay too.
	 */
	public static void setUpMainOverlay(Frame frame){
		
		List<Text> list = frame.getBodyTextItems(true);
		
		boolean found = false;
		int i = 0;
		
		while(i < list.size() && !found){
			
			Text text = list.get(i);
			
			if(text.getText().equals(AO_TEXT3)){
				if(text.hasLink()){
					if(text.getLink().equals(MAIN_INTERFACE_OVERLAY)){
						found = true;
					}
					
				}
			}
			i++;
		}
		
		if(!found){
			Text t = frame.addText(_mainOverAoX,_mainOverAoY,AO_TEXT3,null);
			t.setLink(MAIN_INTERFACE_OVERLAY);
			
			frame.setSaved();
			frame.setChanged(true);
		}
		
		FrameKeyboardActions.Refresh();
	}
	

	/**
	 * Set up overlay which displays toolbar for collection items.
	 * @param cItem - the collection item to add the toolbar to (or rather its represented frame).
	 */
	public static void setUpToolbarOverlay(CollectionItem cItem) {
		
		Frame ciFrame = cItem.getFrame();
		List<Text> list = ciFrame.getBodyTextItems(true);
		
		boolean found = false;
		int i = 0;
		
		while(i < list.size() && !found){
			
			Text t = list.get(i);
			
			if(t.getText().equals(AO_TEXT3)){
				
				if(t.hasLink()){
					if(t.getLink().equals(NAVIGATION_OVERLAY)){
						found = true;
					}
				}
			}
			
			i++;
		}
		
		if(!found){
			
			Text newText = ciFrame.addText(_toolbarAoX,_toolbarAoY,AO_TEXT3,null);
			newText.setLink(NAVIGATION_OVERLAY);
		}
	
		
	}

	/**
	 * Method to set up overlay which displays a "toggle toolbar" option/button.
	 * @param cItem - the collection item to add the toggle toolbar option to.
	 */
	public static void setUpToggleToolbarOverlay(CollectionItem cItem) {
		Frame ciFrame = cItem.getFrame();
		List<Text> list = ciFrame.getBodyTextItems(true);
		
		boolean found = false;
		int i = 0;
		
		while(i < list.size() && !found){
			
			Text t = list.get(i);
			
			if(t.getText().equals(AO_TEXT3)){
				
				if(t.hasLink()){
					
					if(t.getLink().equals(TOGGLE_TOOLS_OVERLAY)){
						found = true;
					}
				}
			}
			i++;
		}
		
		if(!found){
			Text newText = ciFrame.addText(_toggleAoX,_toggleAoY,AO_TEXT3,null);
			newText.setLink(TOGGLE_TOOLS_OVERLAY);
		}
		
	}

	/**
	 * Method to set up an overlay for displaying notes for
	 * the passed collection item.
	 * @param cItem - collection item to add notes to.
	 */
	public static void setUpNotesOverlay(CollectionItem cItem) {
		
		Frame ciFrame = cItem.getFrame();
		List<Text> list = ciFrame.getBodyTextItems(true);
		
		boolean found = false;
		int i = 0;
		
		while(i < list.size() && !found){
			
			Text t = list.get(i);
			
			if(t.getText().equals(AO_TEXT4)){
				
				if(t.hasLink()){
					
					if(t.getLink().startsWith("notes")){
						found = true;
					}
					
				}
			}
			
			i++;
		}
		
		if(!found){
			
			//check for an overlay frame in notes frameset associated with this collection item.
			NoteLayer getNoteLayer = cItem.getNoteLayer();
			Frame getNotesOverlayFrame = null;
			
			if(getNoteLayer == null){
				
				//Create a new notelayer and frame
				getNoteLayer = new NoteLayer();
				getNoteLayer.setAssociatedItem(cItem);
				
				//Create new frame.
				int frameNumber = FrameIO.getLastNumber("notesmain") + 1;
				HonoursFrameIO.generateFrame(frameNumber, "notesmain");
				getNotesOverlayFrame = FrameIO.LoadFrame("notesmain"+frameNumber);
				getNoteLayer.setFrame(FrameIO.LoadFrame(getNotesOverlayFrame.getName()));
				cItem.setNoteLayer(getNoteLayer);
				
				//Add collectionItem back into collection
				//Add collection back into collections list
				Collection matchingCollection = Collection.findCollection(cItem.getFrame());
				int collectionIndex = Collection.getCollectionPosition(matchingCollection);
				int collectionItemPosition = CollectionItem.getPositionInCollection(cItem, matchingCollection);
				
				matchingCollection.getItems().remove(collectionItemPosition);
				matchingCollection.getItems().add(collectionItemPosition,cItem);
				
				Main._collections.remove(collectionIndex);
				Main._collections.add(collectionIndex, matchingCollection);
			}else{
				getNotesOverlayFrame = getNoteLayer.getFrame();
			}
			
			Text newText = ciFrame.addText(_notesAoX,_notesAoY,AO_TEXT4,null);
			newText.setLink(getNotesOverlayFrame.getName());
		}
	}
	
}
